@@ -5,6 +5,7 @@
 from .reports import Reports
 from .projects import Projects
 from .categories import Categories
+from .expenses import Expenses
 from ..version import version
 
 role = 'approver'
@@ -12,3 +13,4 @@ role = 'approver'
 reports = Reports(version, role)
 projects = Projects(version, role)
 categories = Categories(version, role)
+expenses = Expenses(version, role)
