@@ -14,6 +14,11 @@ def get_mock_data_from_file(filename):
   mock_data_dict = get_mock_data_dict(filename)
   mock_data = Mock()
   mock_data.profile.get.return_value = mock_data_dict['profile']
+  mock_data.files_create.get.return_value = mock_data_dict['files_create']
+  mock_data.file_generate_url.get.return_value = mock_data_dict['file_generate_url']
+  mock_data.attach_receipt.get.return_value = mock_data_dict['attach_receipt']
+  mock_data.create_expense.get.return_value = mock_data_dict['create_expense']
+
   return mock_data
 
 
